@@ -6,7 +6,7 @@ module GirFFI
     module SafeFunctionName
       def safe_name
         name = self.name
-        return '_' if name.empty?
+        return "_" if name.empty?
 
         name
       end
@@ -14,4 +14,4 @@ module GirFFI
   end
 end
 
-GObjectIntrospection::IFunctionInfo.send :include, GirFFI::InfoExt::SafeFunctionName
+GObjectIntrospection::IFunctionInfo.include GirFFI::InfoExt::SafeFunctionName
