@@ -13,6 +13,8 @@ module GirFFI
       @klass = klass
       @properties = []
       @vfunc_implementations = []
+
+      # FIXME: Limit access to only install_property and install_vfunc_implementation.
       yield self if block_given?
     end
 
@@ -25,7 +27,6 @@ module GirFFI
     end
 
     def install_vfunc_implementation(name, implementation = nil)
-      implementation ||= ->(obj, *args) { obj.public_send name, *args }
       @vfunc_implementations << VFuncImplementation.new(name, implementation)
     end
 
@@ -51,7 +52,7 @@ module GirFFI
 
     # TODO: Create custom class that includes the interfaces instead
     def class_struct
-      parent.class_struct
+      nil
     end
 
     def interfaces
